@@ -534,7 +534,8 @@ def mock_trainml(
     mock_providers,
 ):
     trainml = create_autospec(TrainML)
-    trainml.active_project = None
+    trainml.active_project = "proj-id-a"
+    trainml.project = "proj-id-a"
     trainml.datasets = create_autospec(Datasets)
     trainml.models = create_autospec(Models)
     trainml.gpu_types = create_autospec(GpuTypes)
