@@ -46,6 +46,7 @@ def job(mock_trainml):
             "worker_status": "new",
             "resources": {
                 "gpu_count": 1,
+                "gpu_types": ["1060-id"],
                 "gpu_type_id": "1060-id",
                 "disk_size": 10,
                 "max_price": 10,
@@ -327,6 +328,23 @@ class JobsTests:
             "/job", "POST", None, expected_payload
         )
 
+    async def test_job_missing_gpu_type(
+        self,
+        jobs,
+    ):
+        requested_config = dict(
+            name="job_name",
+            type="notebook",
+            disk_size=10,
+        )
+
+        with raises(SpecificationError) as error:
+            await jobs.create(**requested_config)
+        assert (
+            "Invalid resource specification, either 'gpu_type' or 'gpu_types' must be provided"
+            in error.value.message
+        )
+
 
 class JobTests:
     def test_job_properties(self, job):
@@ -358,7 +376,10 @@ class JobTests:
         mock_trainml._query = AsyncMock(return_value=api_response)
         await job.start()
         mock_trainml._query.assert_called_once_with(
-            "/job/job-id-1", "PATCH", None, dict(command="start")
+            "/job/job-id-1",
+            "PATCH",
+            dict(project_uuid="proj-id-1"),
+            dict(command="start"),
         )
 
     @mark.asyncio
@@ -367,7 +388,10 @@ class JobTests:
         mock_trainml._query = AsyncMock(return_value=api_response)
         await job.stop()
         mock_trainml._query.assert_called_once_with(
-            "/job/job-id-1", "PATCH", None, dict(command="stop")
+            "/job/job-id-1",
+            "PATCH",
+            dict(project_uuid="proj-id-1"),
+            dict(command="stop"),
         )
 
     @mark.asyncio
@@ -377,7 +401,9 @@ class JobTests:
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await job.get_worker_log_url("worker-id-1")
         mock_trainml._query.assert_called_once_with(
-            "/job/job-id-1/worker/worker-id-1/logs", "GET"
+            "/job/job-id-1/worker/worker-id-1/logs",
+            "GET",
+            dict(project_uuid="proj-id-1"),
         )
         assert response == api_response
 
@@ -388,7 +414,7 @@ class JobTests:
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await job.get_connection_utility_url()
         mock_trainml._query.assert_called_once_with(
-            "/job/job-id-1/download", "GET"
+            "/job/job-id-1/download", "GET", dict(project_uuid="proj-id-1")
         )
         assert response == api_response
 
@@ -519,7 +545,9 @@ class JobTests:
         mock_trainml._query = AsyncMock(return_value=api_response)
         await job.remove()
         mock_trainml._query.assert_called_once_with(
-            "/job/job-id-1", "DELETE", dict(force=False)
+            "/job/job-id-1",
+            "DELETE",
+            dict(project_uuid="proj-id-1", force=False),
         )
 
     @mark.asyncio
@@ -533,7 +561,9 @@ class JobTests:
         }
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await job.refresh()
-        mock_trainml._query.assert_called_once_with("/job/job-id-1", "GET")
+        mock_trainml._query.assert_called_once_with(
+            "/job/job-id-1", "GET", dict(project_uuid="proj-id-1")
+        )
         assert job.status == "running"
         assert response.status == "running"
 
@@ -684,8 +714,10 @@ class JobTests:
         )
         expected_kwargs = {
             "type": "notebook",
-            "gpu_type": "1060-id",
+            "gpu_type": None,
+            "gpu_types": ["1060-id"],
             "gpu_count": 1,
+            "cpu_count": None,
             "disk_size": 10,
             "max_price": 10,
             "worker_commands": None,
@@ -743,7 +775,9 @@ class JobTests:
         }
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await job.wait_for("running")
-        mock_trainml._query.assert_called_once_with("/job/job-id-1", "GET")
+        mock_trainml._query.assert_called_once_with(
+            "/job/job-id-1", "GET", dict(project_uuid="proj-id-1")
+        )
         assert job.status == "running"
         assert response.status == "running"
 
