@@ -26,7 +26,7 @@ def model(mock_trainml):
     yield specimen.Model(
         mock_trainml,
         model_uuid="1",
-        project_uuid="a",
+        project_uuid="proj-id-a",
         name="first one",
         status="new",
         size=100000,
@@ -135,7 +135,9 @@ class ModelTests:
         api_response = "https://trainml-jobs-dev.s3.us-east-2.amazonaws.com/1/logs/first_one.zip"
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await model.get_log_url()
-        mock_trainml._query.assert_called_once_with("/model/pub/1/logs", "GET")
+        mock_trainml._query.assert_called_once_with(
+            "/model/pub/1/logs", "GET", dict(project_uuid="proj-id-a")
+        )
         assert response == api_response
 
     @mark.asyncio
@@ -151,7 +153,7 @@ class ModelTests:
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await model.get_details()
         mock_trainml._query.assert_called_once_with(
-            "/model/pub/1/details", "GET"
+            "/model/pub/1/details", "GET", dict(project_uuid="proj-id-a")
         )
         assert response == api_response
 
@@ -162,7 +164,7 @@ class ModelTests:
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await model.get_connection_utility_url()
         mock_trainml._query.assert_called_once_with(
-            "/model/pub/1/download", "GET"
+            "/model/pub/1/download", "GET", dict(project_uuid="proj-id-a")
         )
         assert response == api_response
 
@@ -235,7 +237,9 @@ class ModelTests:
         mock_trainml._query = AsyncMock(return_value=api_response)
         await model.remove()
         mock_trainml._query.assert_called_once_with(
-            "/model/pub/1", "DELETE", dict(force=False)
+            "/model/pub/1",
+            "DELETE",
+            dict(project_uuid="proj-id-a", force=False),
         )
 
     def test_model_default_ws_msg_handler(self, model, capsys):
@@ -324,7 +328,9 @@ class ModelTests:
         }
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await model.refresh()
-        mock_trainml._query.assert_called_once_with(f"/model/pub/1", "GET")
+        mock_trainml._query.assert_called_once_with(
+            f"/model/pub/1", "GET", dict(project_uuid="proj-id-a")
+        )
         assert model.id == "data-id-1"
         assert response.id == "data-id-1"
 
@@ -341,7 +347,9 @@ class ModelTests:
         }
         mock_trainml._query = AsyncMock(return_value=api_response)
         response = await model.wait_for("ready")
-        mock_trainml._query.assert_called_once_with(f"/model/pub/1", "GET")
+        mock_trainml._query.assert_called_once_with(
+            f"/model/pub/1", "GET", dict(project_uuid="proj-id-a")
+        )
         assert model.id == "data-id-1"
         assert response.id == "data-id-1"
 
