@@ -9,7 +9,12 @@ import re
 import logging
 from datetime import datetime
 
-from .exceptions import ConnectionError, ApiError, SpecificationError
+from .exceptions import (
+    ConnectionError,
+    ApiError,
+    SpecificationError,
+    TrainMLException,
+)
 from aiodocker.exceptions import DockerError
 
 
@@ -72,31 +77,63 @@ class Connections(object):
             con_task = asyncio.create_task(connection._validate_entity())
             con_tasks.append(con_task)
         await asyncio.gather(*con_tasks)
-        await self.cleanup_containers()
+        await self.cleanup_containers(project=self.trainml.project)
         logging.info("Finish cleanup connections")
 
     async def cleanup_containers(self, project=None):
         logging.info("Start cleanup containers")
-        con_dirs = (
-            os.listdir(f"{CONFIG_DIR}/connections/{project}")
-            if project
-            else os.listdir(self.dir)
-        )
-        await asyncio.gather(
-            asyncio.create_task(
-                _cleanup_containers(
-                    project or self.trainml.project, self.dir, con_dirs, "vpn"
-                )
-            ),
-            asyncio.create_task(
-                _cleanup_containers(
-                    project or self.trainml.project,
-                    self.dir,
-                    con_dirs,
-                    "storage",
-                )
-            ),
-        )
+        if project:
+            con_dirs = os.listdir(f"{CONFIG_DIR}/connections/{project}")
+            await asyncio.gather(
+                asyncio.create_task(
+                    _cleanup_containers(
+                        project,
+                        self.dir,
+                        con_dirs,
+                        "vpn",
+                    )
+                ),
+                asyncio.create_task(
+                    _cleanup_containers(
+                        project,
+                        self.dir,
+                        con_dirs,
+                        "storage",
+                    )
+                ),
+            )
+        else:
+            con_dirs = []
+            proj_dirs = os.listdir(f"{CONFIG_DIR}/connections")
+            logging.info(f"proj_dirs {proj_dirs}")
+            for proj_dir in proj_dirs:
+                con_dirs += [
+                    f"{proj_dir}/{con_dir}"
+                    for con_dir in os.listdir(
+                        f"{CONFIG_DIR}/connections/{project}"
+                    )
+                ]
+
+            logging.info(f"con_dirs {con_dirs}")
+            await asyncio.gather(
+                asyncio.create_task(
+                    _cleanup_containers(
+                        None,
+                        f"{CONFIG_DIR}/connections",
+                        con_dirs,
+                        "vpn",
+                    )
+                ),
+                asyncio.create_task(
+                    _cleanup_containers(
+                        None,
+                        f"{CONFIG_DIR}/connections",
+                        con_dirs,
+                        "storage",
+                    )
+                ),
+            )
+
         logging.info("Finish cleanup containers")
 
     async def remove_all(self, all_projects=False):
@@ -108,14 +145,14 @@ class Connections(object):
                     f"{CONFIG_DIR}/connections/{proj_dir}",
                     exist_ok=True,
                 )
-                await self.cleanup_containers(project=proj_dir)
+            await self.cleanup_containers()
         else:
             shutil.rmtree(self.dir)
             os.makedirs(
                 self.dir,
                 exist_ok=True,
             )
-            await self.cleanup_containers()
+            await self.cleanup_containers(project=self.trainml.project)
 
 
 class Connection:
@@ -253,6 +290,8 @@ class Connection:
             return
 
         docker = aiodocker.Docker()
+        await _check_docker_status(docker)
+
         try:
             container = await docker.containers.get(vpn_id)
         except DockerError as e:
@@ -290,9 +329,7 @@ class Connection:
 
     async def start(self):
         logging.info(f"Beginning start {self.type} connection {self.id}")
-        cleanup_task = asyncio.create_task(
-            self.trainml.connections.cleanup_connections()
-        )
+
         if self.status == STATUSES.get("UNKNOWN"):
             await self.check()
         if self.status in [
@@ -311,6 +348,7 @@ class Connection:
             await self._download_connection_details()
 
         docker = aiodocker.Docker()
+        await _check_docker_status(docker)
         try:
             await asyncio.gather(
                 docker.pull(VPN_IMAGE), docker.pull(STORAGE_IMAGE)
@@ -364,6 +402,10 @@ class Connection:
         with open(f"{self._dir}/vpn_id", "w") as f:
             f.write(vpn_container.id)
 
+        cleanup_task = asyncio.create_task(
+            self.trainml.connections.cleanup_connections()
+        )
+
         count = 0
         while count <= 30:
             logging.debug(f"Test connectivity attempt {count+1}")
@@ -386,6 +428,8 @@ class Connection:
         if not self._entity:
             await self._get_entity()
         docker = aiodocker.Docker()
+        await _check_docker_status(docker)
+
         tasks = []
         logging.info("Disconnecting...")
         try:
@@ -434,17 +478,27 @@ async def _cleanup_containers(project, path, con_dirs, type):
             continue
 
     docker = aiodocker.Docker()
+    await _check_docker_status(docker)
+
+    if project:
+        filter = dict(
+            label=[
+                "service=trainml",
+                f"type={type}",
+                f"project={project}",
+            ]
+        )
+    else:
+        filter = dict(
+            label=[
+                "service=trainml",
+                f"type={type}",
+            ]
+        )
+
     containers = await docker.containers.list(
         all=True,
-        filters=json.dumps(
-            dict(
-                label=[
-                    "service=trainml",
-                    f"type={type}",
-                    f"project={project}",
-                ]
-            )
-        ),
+        filters=json.dumps(filter),
     )
 
     tasks = [
@@ -551,4 +605,16 @@ async def _image_exists(client, id):
         await client.images.inspect(id)
         return True
     except DockerError:
-        return False
\ No newline at end of file
+        return False
+
+
+async def _check_docker_status(client):
+    try:
+        await client.version()
+    except DockerError:
+        raise TrainMLException(
+            "Docker is not installed, not running, or your user does not have docker privileges. "
+            + "Ensure docker is installed, then add your user to the docker group. "
+            + "Commonly, this is accomplished by entering 'sudo gpasswd -a <username> docker'. "
+            + "You may need to logout and log back in to your computer for this to take effect"
+        )
